@@ -29,43 +29,45 @@ gmHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
            ## So we can estimate live TPA at t2 (t1 unavailable w/out growth accounting) with:
            TPA_UNADJ = TPA_UNADJ * state_recr * if_else(STATUSCD == 1 & DIA >= 5, 1, 0),
            aChng = ifelse(COND_STATUS_CD == 1 & COND_STATUS_CD.prev == 1 & !is.null(CONDPROP_UNADJ), 1, 0),
-           tChng = ifelse(COND_STATUS_CD == 1 & COND_STATUS_CD.prev == 1, 1, 0),
-           test = if_else(COMPONENT %in% c('INGROWTH', 'CUT2', 'MORTALITY2'), 1, 0))
+           tChng = ifelse(COND_STATUS_CD == 1 & COND_STATUS_CD.prev == 1, 1, 0))
 
 
   # If previous attributes are unavailable for trees, default to current (otherwise we get NAs for early inventories)
   data$tD.prev <- ifelse(is.na(data$tD.prev), data$tD, data$tD.prev)
   data$typeD.prev <- ifelse(is.na(data$typeD.prev), data$typeD, data$typeD.prev)
-  data$landD.prev <- ifelse(is.na(data$landD.prev), data$landD, data$landD.prev)
+  data$landD.prev.noga <- ifelse(is.na(data$landD.prev), data$landD, data$landD.prev)
   ## Issue is here for pre-growth accounting
-  #data$landD.prev <- ifelse(data$landD == 1 & data$landD.prev == 1, 1, 0)
+  data$landD.prev.ga <- ifelse(data$landD == 1 & data$landD.prev == 1, 1, 0)
   data$aD_p.prev <- ifelse(is.na(data$aD_p.prev), data$aD_p, data$aD_p.prev)
   data$aD_c.prev <- ifelse(is.na(data$aD_c.prev), data$aD_c, data$aD_c.prev)
   data$sp.prev <- ifelse(is.na(data$sp.prev), data$sp, data$sp.prev)
 
   ## Comprehensive indicator function -- w/ growth accounting
-  data$tDI_ga <- data$landD.prev * data$aD_p.prev * data$aD_c.prev * data$tD.prev * data$typeD.prev * data$sp.prev * data$tChng
+  data$tDI_ga <- data$landD.prev.ga * data$aD_p.prev * data$aD_c.prev * data$tD.prev * data$typeD.prev * data$sp.prev * data$tChng
   data$tDI_ga_r <- data$landD * data$aD_p * data$aD_c * data$tD * data$typeD * data$sp * data$tChng
 
   ## Comprehensive indicator function
   data$aDI <- data$landD * data$aD_p * data$aD_c * data$sp
-  data$tDI <- data$landD.prev * data$aD_p.prev * data$aD_c.prev * data$tD.prev * data$typeD.prev * data$sp.prev
+  data$tDI <- data$landD.prev.noga * data$aD_p.prev * data$aD_c.prev * data$tD.prev * data$typeD.prev * data$sp.prev
   data$tDI_r <- data$landD * data$aD_p * data$aD_c * data$tD * data$typeD * data$sp
 
-  ### DOING AREA SEPARATELY NOW FOR GROWTH ACCOUNTING PLOTS
-  aData <- select(db$PLOT,c('PLT_CN', 'STATECD', 'MACRO_BREAKPOINT_DIA', 'INVYR', 'MEASYEAR', 'PLOT_STATUS_CD', 'PREV_PLT_CN', 'REMPER', grpP, 'aD_p', 'sp')) %>%
-    left_join(select(db$SUBP_COND_CHNG_MTRX, PLT_CN, PREV_PLT_CN, SUBPTYP, SUBPTYP_PROP_CHNG, PREVCOND, CONDID), by = c('PLT_CN', 'PREV_PLT_CN')) %>%
-    left_join(select(db$COND, c('PLT_CN', 'CONDPROP_UNADJ', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', grpC, 'aD_c', 'landD')), by = c('PLT_CN', 'CONDID')) %>%
-    left_join(select(db$COND, c('PLT_CN', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', grpC, 'aD_c', 'landD')), by = c('PREV_PLT_CN' = 'PLT_CN', 'PREVCOND' = 'CONDID'), suffix = c('', '.prev')) %>%
-    mutate(aChng = if_else(COND_STATUS_CD == 1 &
-                             COND_STATUS_CD.prev == 1 &
-                             !is.null(CONDPROP_UNADJ) &
-                             SUBPTYP == 1,
-                           1, 0),
-           SUBPTYP_PROP_CHNG = SUBPTYP_PROP_CHNG * .25)
+  if ('SUBP_COND_CHNG_MTRX' %in% names(db)) {
+    ### DOING AREA SEPARATELY NOW FOR GROWTH ACCOUNTING PLOTS
+    aData <- select(db$PLOT,c('PLT_CN', 'STATECD', 'MACRO_BREAKPOINT_DIA', 'INVYR', 'MEASYEAR', 'PLOT_STATUS_CD', 'PREV_PLT_CN', 'REMPER', grpP, 'aD_p', 'sp')) %>%
+      left_join(select(db$SUBP_COND_CHNG_MTRX, PLT_CN, PREV_PLT_CN, SUBPTYP, SUBPTYP_PROP_CHNG, PREVCOND, CONDID), by = c('PLT_CN', 'PREV_PLT_CN')) %>%
+      left_join(select(db$COND, c('PLT_CN', 'CONDPROP_UNADJ', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', grpC, 'aD_c', 'landD')), by = c('PLT_CN', 'CONDID')) %>%
+      left_join(select(db$COND, c('PLT_CN', 'PROP_BASIS', 'COND_STATUS_CD', 'CONDID', grpC, 'aD_c', 'landD')), by = c('PREV_PLT_CN' = 'PLT_CN', 'PREVCOND' = 'CONDID'), suffix = c('', '.prev')) %>%
+      mutate(aChng = if_else(COND_STATUS_CD == 1 &
+                               COND_STATUS_CD.prev == 1 &
+                               !is.null(CONDPROP_UNADJ) &
+                               SUBPTYP == 1,
+                             1, 0),
+             SUBPTYP_PROP_CHNG = SUBPTYP_PROP_CHNG * .25)
 
-  aData$landD <- ifelse(aData$landD == 1 & aData$landD.prev == 1, 1, 0)
-  aData$aDI_ga <- aData$landD * aData$aD_p * aData$aD_c * aData$sp * aData$aChng
+    aData$landD <- ifelse(aData$landD == 1 & aData$landD.prev == 1, 1, 0)
+    aData$aDI_ga <- aData$landD * aData$aD_p * aData$aD_c * aData$sp * aData$aChng
+
+  }
 
 
   if (byPlot){
@@ -90,14 +92,7 @@ gmHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
     a = NULL
 
   } else {
-    ### Plot-level estimates -- growth accounting
-    a_ga <- aData %>%
-      ## Will be lots of trees here, so CONDPROP listed multiple times
-      ## Adding PROP_BASIS so we can handle adjustment factors at strata level
-      #distinct(PLT_CN, SUBP, CONDID, .keep_all = TRUE) %>%
-      group_by(PLT_CN, PROP_BASIS, .dots = aGrpBy) %>%
-      summarize(fa_ga = sum(SUBPTYP_PROP_CHNG * aDI_ga, na.rm = TRUE),
-                plotIn_ga = ifelse(sum(aDI_ga >  0, na.rm = TRUE), 1,0))
+
     ### Plot-level estimates
     a <- data %>%
       ## Will be lots of trees here, so CONDPROP listed multiple times
@@ -105,8 +100,26 @@ gmHelper1 <- function(x, plts, db, grpBy, aGrpBy, byPlot){
       distinct(PLT_CN, CONDID, .keep_all = TRUE) %>%
       group_by(PLT_CN, PROP_BASIS, .dots = aGrpBy) %>%
       summarize(fa = sum(CONDPROP_UNADJ * aDI, na.rm = TRUE),
-                plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0)) %>%
-      left_join(select(a_ga, PLT_CN, PROP_BASIS, aGrpBy, fa_ga, plotIn_ga), by = c('PLT_CN', 'PROP_BASIS', aGrpBy))
+                plotIn = ifelse(sum(aDI >  0, na.rm = TRUE), 1,0))
+
+    if ('SUBP_COND_CHNG_MTRX' %in% names(db)) {
+      ### Plot-level estimates -- growth accounting
+      a_ga <- aData %>%
+        ## Will be lots of trees here, so CONDPROP listed multiple times
+        ## Adding PROP_BASIS so we can handle adjustment factors at strata level
+        #distinct(PLT_CN, SUBP, CONDID, .keep_all = TRUE) %>%
+        group_by(PLT_CN, PROP_BASIS, .dots = aGrpBy) %>%
+        summarize(fa_ga = sum(SUBPTYP_PROP_CHNG * aDI_ga, na.rm = TRUE),
+                  plotIn_ga = ifelse(sum(aDI_ga >  0, na.rm = TRUE), 1,0))
+
+      a <- a %>%
+        left_join(select(a_ga, PLT_CN, PROP_BASIS, aGrpBy, fa_ga, plotIn_ga), by = c('PLT_CN', 'PROP_BASIS', aGrpBy))
+    } else {
+      a <- a %>%
+        mutate(fa_ga = fa,
+               plotIn_ga = plotIn)
+    }
+
 
     grpSyms <- syms(grpBy)
 
